# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['EcsNetworkInterfacePermissionArgs', 'EcsNetworkInterfacePermission']

@pulumi.input_type
class EcsNetworkInterfacePermissionArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[str],
                 network_interface_id: pulumi.Input[str],
                 permission: pulumi.Input[str],
                 force: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a EcsNetworkInterfacePermission resource.
        :param pulumi.Input[str] account_id: Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        :param pulumi.Input[str] network_interface_id: The ID of the network interface.
        :param pulumi.Input[str] permission: The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        :param pulumi.Input[bool] force: Whether to force deletion of Network Interface Permission. Default value: `true`.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "network_interface_id", network_interface_id)
        pulumi.set(__self__, "permission", permission)
        if force is not None:
            pulumi.set(__self__, "force", force)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[str]:
        """
        Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Input[str]:
        """
        The ID of the network interface.
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter
    def permission(self) -> pulumi.Input[str]:
        """
        The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: pulumi.Input[str]):
        pulumi.set(self, "permission", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to force deletion of Network Interface Permission. Default value: `true`.
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force", value)


@pulumi.input_type
class _EcsNetworkInterfacePermissionState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 network_interface_id: Optional[pulumi.Input[str]] = None,
                 permission: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EcsNetworkInterfacePermission resources.
        :param pulumi.Input[str] account_id: Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        :param pulumi.Input[bool] force: Whether to force deletion of Network Interface Permission. Default value: `true`.
        :param pulumi.Input[str] network_interface_id: The ID of the network interface.
        :param pulumi.Input[str] permission: The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        :param pulumi.Input[str] status: The Status of the Network Interface Permissions. Valid values: `Pending`, `Granted`, `Revoking`, `Revoked`.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to force deletion of Network Interface Permission. Default value: `true`.
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the network interface.
        """
        return pulumi.get(self, "network_interface_id")

    @network_interface_id.setter
    def network_interface_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_interface_id", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[str]]:
        """
        The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "permission", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The Status of the Network Interface Permissions. Valid values: `Pending`, `Granted`, `Revoking`, `Revoked`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class EcsNetworkInterfacePermission(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 network_interface_id: Optional[pulumi.Input[str]] = None,
                 permission: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ECS Network Interface Permission resource.

        For information about ECS Network Interface Permission and how to use it, see [What is Network Interface Permission](https://www.alibabacloud.com/help/en/elastic-compute-service/latest/elastic-network-interfaces-overview).

        > **NOTE:** Available in v1.166.0+.

        ## Import

        ECS Network Interface Permission can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecs/ecsNetworkInterfacePermission:EcsNetworkInterfacePermission example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_id: Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        :param pulumi.Input[bool] force: Whether to force deletion of Network Interface Permission. Default value: `true`.
        :param pulumi.Input[str] network_interface_id: The ID of the network interface.
        :param pulumi.Input[str] permission: The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EcsNetworkInterfacePermissionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECS Network Interface Permission resource.

        For information about ECS Network Interface Permission and how to use it, see [What is Network Interface Permission](https://www.alibabacloud.com/help/en/elastic-compute-service/latest/elastic-network-interfaces-overview).

        > **NOTE:** Available in v1.166.0+.

        ## Import

        ECS Network Interface Permission can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ecs/ecsNetworkInterfacePermission:EcsNetworkInterfacePermission example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EcsNetworkInterfacePermissionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcsNetworkInterfacePermissionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 network_interface_id: Optional[pulumi.Input[str]] = None,
                 permission: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcsNetworkInterfacePermissionArgs.__new__(EcsNetworkInterfacePermissionArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["force"] = force
            if network_interface_id is None and not opts.urn:
                raise TypeError("Missing required property 'network_interface_id'")
            __props__.__dict__["network_interface_id"] = network_interface_id
            if permission is None and not opts.urn:
                raise TypeError("Missing required property 'permission'")
            __props__.__dict__["permission"] = permission
            __props__.__dict__["status"] = None
        super(EcsNetworkInterfacePermission, __self__).__init__(
            'alicloud:ecs/ecsNetworkInterfacePermission:EcsNetworkInterfacePermission',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[str]] = None,
            force: Optional[pulumi.Input[bool]] = None,
            network_interface_id: Optional[pulumi.Input[str]] = None,
            permission: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'EcsNetworkInterfacePermission':
        """
        Get an existing EcsNetworkInterfacePermission resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_id: Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        :param pulumi.Input[bool] force: Whether to force deletion of Network Interface Permission. Default value: `true`.
        :param pulumi.Input[str] network_interface_id: The ID of the network interface.
        :param pulumi.Input[str] permission: The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        :param pulumi.Input[str] status: The Status of the Network Interface Permissions. Valid values: `Pending`, `Granted`, `Revoking`, `Revoked`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcsNetworkInterfacePermissionState.__new__(_EcsNetworkInterfacePermissionState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["force"] = force
        __props__.__dict__["network_interface_id"] = network_interface_id
        __props__.__dict__["permission"] = permission
        __props__.__dict__["status"] = status
        return EcsNetworkInterfacePermission(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[str]:
        """
        Alibaba Cloud Partner (Certified ISV) account ID or individual user ID.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def force(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to force deletion of Network Interface Permission. Default value: `true`.
        """
        return pulumi.get(self, "force")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> pulumi.Output[str]:
        """
        The ID of the network interface.
        """
        return pulumi.get(self, "network_interface_id")

    @property
    @pulumi.getter
    def permission(self) -> pulumi.Output[str]:
        """
        The permissions of the Network Interface. Valid values: `InstanceAttach`. `InstanceAttach`: Allows authorized users to mount your ENI to the other ECS instance. The ECS instance must be in the same zone as the ENI.
        """
        return pulumi.get(self, "permission")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The Status of the Network Interface Permissions. Valid values: `Pending`, `Granted`, `Revoking`, `Revoked`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetFileCrc64ChecksumResult',
    'AwaitableGetFileCrc64ChecksumResult',
    'get_file_crc64_checksum',
    'get_file_crc64_checksum_output',
]

@pulumi.output_type
class GetFileCrc64ChecksumResult:
    """
    A collection of values returned by getFileCrc64Checksum.
    """
    def __init__(__self__, checksum=None, filename=None, id=None, output_file=None):
        if checksum and not isinstance(checksum, str):
            raise TypeError("Expected argument 'checksum' to be a str")
        pulumi.set(__self__, "checksum", checksum)
        if filename and not isinstance(filename, str):
            raise TypeError("Expected argument 'filename' to be a str")
        pulumi.set(__self__, "filename", filename)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def checksum(self) -> str:
        """
        the file checksum of crc64.
        """
        return pulumi.get(self, "checksum")

    @property
    @pulumi.getter
    def filename(self) -> str:
        return pulumi.get(self, "filename")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetFileCrc64ChecksumResult(GetFileCrc64ChecksumResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFileCrc64ChecksumResult(
            checksum=self.checksum,
            filename=self.filename,
            id=self.id,
            output_file=self.output_file)


def get_file_crc64_checksum(filename: Optional[str] = None,
                            output_file: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFileCrc64ChecksumResult:
    """
    This data source compute file crc64 checksum.

    > **NOTE:** Available in 1.59.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.get_file_crc64_checksum(filename="exampleFileName")
    pulumi.export("fileCrc64Checksum", data["alicloud_file_crc64_checksum"]["defualt"]["checksum"])
    ```


    :param str filename: The name of the file to be computed crc64 checksum.
    """
    __args__ = dict()
    __args__['filename'] = filename
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:index/getFileCrc64Checksum:getFileCrc64Checksum', __args__, opts=opts, typ=GetFileCrc64ChecksumResult).value

    return AwaitableGetFileCrc64ChecksumResult(
        checksum=pulumi.get(__ret__, 'checksum'),
        filename=pulumi.get(__ret__, 'filename'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'))


@_utilities.lift_output_func(get_file_crc64_checksum)
def get_file_crc64_checksum_output(filename: Optional[pulumi.Input[str]] = None,
                                   output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFileCrc64ChecksumResult]:
    """
    This data source compute file crc64 checksum.

    > **NOTE:** Available in 1.59.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.get_file_crc64_checksum(filename="exampleFileName")
    pulumi.export("fileCrc64Checksum", data["alicloud_file_crc64_checksum"]["defualt"]["checksum"])
    ```


    :param str filename: The name of the file to be computed crc64 checksum.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NestServiceInstanceArgs', 'NestServiceInstance']

@pulumi.input_type
class NestServiceInstanceArgs:
    def __init__(__self__, *,
                 service_id: pulumi.Input[str],
                 service_version: pulumi.Input[str],
                 commodity: Optional[pulumi.Input['NestServiceInstanceCommodityArgs']] = None,
                 enable_instance_ops: Optional[pulumi.Input[bool]] = None,
                 enable_user_prometheus: Optional[pulumi.Input[bool]] = None,
                 operation_metadata: Optional[pulumi.Input['NestServiceInstanceOperationMetadataArgs']] = None,
                 parameters: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_instance_name: Optional[pulumi.Input[str]] = None,
                 specification_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 template_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NestServiceInstance resource.
        :param pulumi.Input[str] service_id: The ID of the service.
        :param pulumi.Input[str] service_version: The version of the service.
        :param pulumi.Input['NestServiceInstanceCommodityArgs'] commodity: The order information of cloud market. See the following `Block commodity`.
        :param pulumi.Input[bool] enable_instance_ops: Whether the service instance has the O&M function. Default value: `false`. Valid values:
        :param pulumi.Input[bool] enable_user_prometheus: Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        :param pulumi.Input['NestServiceInstanceOperationMetadataArgs'] operation_metadata: The configuration of O&M. See the following `Block operation_metadata`.
        :param pulumi.Input[str] parameters: The parameters entered by the deployment service instance.
        :param pulumi.Input[str] payment_type: The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] service_instance_name: The name of the Service Instance.
        :param pulumi.Input[str] specification_name: The name of the specification.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] template_name: The name of the template.
        """
        pulumi.set(__self__, "service_id", service_id)
        pulumi.set(__self__, "service_version", service_version)
        if commodity is not None:
            pulumi.set(__self__, "commodity", commodity)
        if enable_instance_ops is not None:
            pulumi.set(__self__, "enable_instance_ops", enable_instance_ops)
        if enable_user_prometheus is not None:
            pulumi.set(__self__, "enable_user_prometheus", enable_user_prometheus)
        if operation_metadata is not None:
            pulumi.set(__self__, "operation_metadata", operation_metadata)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if service_instance_name is not None:
            pulumi.set(__self__, "service_instance_name", service_instance_name)
        if specification_name is not None:
            pulumi.set(__self__, "specification_name", specification_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_name is not None:
            pulumi.set(__self__, "template_name", template_name)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Input[str]:
        """
        The ID of the service.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceVersion")
    def service_version(self) -> pulumi.Input[str]:
        """
        The version of the service.
        """
        return pulumi.get(self, "service_version")

    @service_version.setter
    def service_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_version", value)

    @property
    @pulumi.getter
    def commodity(self) -> Optional[pulumi.Input['NestServiceInstanceCommodityArgs']]:
        """
        The order information of cloud market. See the following `Block commodity`.
        """
        return pulumi.get(self, "commodity")

    @commodity.setter
    def commodity(self, value: Optional[pulumi.Input['NestServiceInstanceCommodityArgs']]):
        pulumi.set(self, "commodity", value)

    @property
    @pulumi.getter(name="enableInstanceOps")
    def enable_instance_ops(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the service instance has the O&M function. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_instance_ops")

    @enable_instance_ops.setter
    def enable_instance_ops(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_instance_ops", value)

    @property
    @pulumi.getter(name="enableUserPrometheus")
    def enable_user_prometheus(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_user_prometheus")

    @enable_user_prometheus.setter
    def enable_user_prometheus(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_user_prometheus", value)

    @property
    @pulumi.getter(name="operationMetadata")
    def operation_metadata(self) -> Optional[pulumi.Input['NestServiceInstanceOperationMetadataArgs']]:
        """
        The configuration of O&M. See the following `Block operation_metadata`.
        """
        return pulumi.get(self, "operation_metadata")

    @operation_metadata.setter
    def operation_metadata(self, value: Optional[pulumi.Input['NestServiceInstanceOperationMetadataArgs']]):
        pulumi.set(self, "operation_metadata", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[str]]:
        """
        The parameters entered by the deployment service instance.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="serviceInstanceName")
    def service_instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Service Instance.
        """
        return pulumi.get(self, "service_instance_name")

    @service_instance_name.setter
    def service_instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_instance_name", value)

    @property
    @pulumi.getter(name="specificationName")
    def specification_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the specification.
        """
        return pulumi.get(self, "specification_name")

    @specification_name.setter
    def specification_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "specification_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the template.
        """
        return pulumi.get(self, "template_name")

    @template_name.setter
    def template_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_name", value)


@pulumi.input_type
class _NestServiceInstanceState:
    def __init__(__self__, *,
                 commodity: Optional[pulumi.Input['NestServiceInstanceCommodityArgs']] = None,
                 enable_instance_ops: Optional[pulumi.Input[bool]] = None,
                 enable_user_prometheus: Optional[pulumi.Input[bool]] = None,
                 operation_metadata: Optional[pulumi.Input['NestServiceInstanceOperationMetadataArgs']] = None,
                 parameters: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_instance_name: Optional[pulumi.Input[str]] = None,
                 service_version: Optional[pulumi.Input[str]] = None,
                 specification_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 template_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NestServiceInstance resources.
        :param pulumi.Input['NestServiceInstanceCommodityArgs'] commodity: The order information of cloud market. See the following `Block commodity`.
        :param pulumi.Input[bool] enable_instance_ops: Whether the service instance has the O&M function. Default value: `false`. Valid values:
        :param pulumi.Input[bool] enable_user_prometheus: Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        :param pulumi.Input['NestServiceInstanceOperationMetadataArgs'] operation_metadata: The configuration of O&M. See the following `Block operation_metadata`.
        :param pulumi.Input[str] parameters: The parameters entered by the deployment service instance.
        :param pulumi.Input[str] payment_type: The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] service_id: The ID of the service.
        :param pulumi.Input[str] service_instance_name: The name of the Service Instance.
        :param pulumi.Input[str] service_version: The version of the service.
        :param pulumi.Input[str] specification_name: The name of the specification.
        :param pulumi.Input[str] status: The status of the Service Instance.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] template_name: The name of the template.
        """
        if commodity is not None:
            pulumi.set(__self__, "commodity", commodity)
        if enable_instance_ops is not None:
            pulumi.set(__self__, "enable_instance_ops", enable_instance_ops)
        if enable_user_prometheus is not None:
            pulumi.set(__self__, "enable_user_prometheus", enable_user_prometheus)
        if operation_metadata is not None:
            pulumi.set(__self__, "operation_metadata", operation_metadata)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_instance_name is not None:
            pulumi.set(__self__, "service_instance_name", service_instance_name)
        if service_version is not None:
            pulumi.set(__self__, "service_version", service_version)
        if specification_name is not None:
            pulumi.set(__self__, "specification_name", specification_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_name is not None:
            pulumi.set(__self__, "template_name", template_name)

    @property
    @pulumi.getter
    def commodity(self) -> Optional[pulumi.Input['NestServiceInstanceCommodityArgs']]:
        """
        The order information of cloud market. See the following `Block commodity`.
        """
        return pulumi.get(self, "commodity")

    @commodity.setter
    def commodity(self, value: Optional[pulumi.Input['NestServiceInstanceCommodityArgs']]):
        pulumi.set(self, "commodity", value)

    @property
    @pulumi.getter(name="enableInstanceOps")
    def enable_instance_ops(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the service instance has the O&M function. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_instance_ops")

    @enable_instance_ops.setter
    def enable_instance_ops(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_instance_ops", value)

    @property
    @pulumi.getter(name="enableUserPrometheus")
    def enable_user_prometheus(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_user_prometheus")

    @enable_user_prometheus.setter
    def enable_user_prometheus(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_user_prometheus", value)

    @property
    @pulumi.getter(name="operationMetadata")
    def operation_metadata(self) -> Optional[pulumi.Input['NestServiceInstanceOperationMetadataArgs']]:
        """
        The configuration of O&M. See the following `Block operation_metadata`.
        """
        return pulumi.get(self, "operation_metadata")

    @operation_metadata.setter
    def operation_metadata(self, value: Optional[pulumi.Input['NestServiceInstanceOperationMetadataArgs']]):
        pulumi.set(self, "operation_metadata", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[str]]:
        """
        The parameters entered by the deployment service instance.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the service.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceInstanceName")
    def service_instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Service Instance.
        """
        return pulumi.get(self, "service_instance_name")

    @service_instance_name.setter
    def service_instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_instance_name", value)

    @property
    @pulumi.getter(name="serviceVersion")
    def service_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the service.
        """
        return pulumi.get(self, "service_version")

    @service_version.setter
    def service_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_version", value)

    @property
    @pulumi.getter(name="specificationName")
    def specification_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the specification.
        """
        return pulumi.get(self, "specification_name")

    @specification_name.setter
    def specification_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "specification_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the Service Instance.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the template.
        """
        return pulumi.get(self, "template_name")

    @template_name.setter
    def template_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_name", value)


class NestServiceInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 commodity: Optional[pulumi.Input[pulumi.InputType['NestServiceInstanceCommodityArgs']]] = None,
                 enable_instance_ops: Optional[pulumi.Input[bool]] = None,
                 enable_user_prometheus: Optional[pulumi.Input[bool]] = None,
                 operation_metadata: Optional[pulumi.Input[pulumi.InputType['NestServiceInstanceOperationMetadataArgs']]] = None,
                 parameters: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_instance_name: Optional[pulumi.Input[str]] = None,
                 service_version: Optional[pulumi.Input[str]] = None,
                 specification_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 template_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Compute Nest Service Instance resource.

        For information about Compute Nest Service Instance and how to use it, see [What is Service Instance](https://help.aliyun.com/document_detail/396194.html).

        > **NOTE:** Available in v1.205.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_resource_groups = alicloud.resourcemanager.get_resource_groups()
        default_zones = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_instance_types = alicloud.ecs.get_instance_types(availability_zone=default_zones.zones[0].id,
            instance_type_family="ecs.sn1ne")
        default_images = alicloud.ecs.get_images(name_regex="^ubuntu_[0-9]+_[0-9]+_x64*",
            most_recent=True,
            owners="system")
        default_networks = alicloud.vpc.get_networks(name_regex="your_name_regex")
        default_switches = alicloud.vpc.get_switches(vpc_id=default_networks.ids[0],
            zone_id=default_zones.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("defaultSecurityGroup", vpc_id=default_networks.ids[0])
        default_instance = alicloud.ecs.Instance("defaultInstance",
            image_id=default_images.images[0].id,
            instance_type=default_instance_types.instance_types[0].id,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default_zones.zones[0].id,
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switches.ids[0])
        default_nest_service_instance = alicloud.compute.NestServiceInstance("defaultNestServiceInstance",
            service_id="service-dd475e6e468348799f0f",
            service_version="1",
            service_instance_name=var["name"],
            resource_group_id=default_resource_groups.groups[0].id,
            payment_type="Permanent",
            operation_metadata=alicloud.compute.NestServiceInstanceOperationMetadataArgs(
                operation_start_time="1681281179000",
                operation_end_time="1681367579000",
                resources=default_instance.id.apply(lambda id: f"{{\\"Type\\":\\"ResourceIds\\",\\"ResourceIds\\":{{\\"ALIYUN::ECS::INSTANCE\\":[\\"{id}\\"]}},\\"RegionId\\":\\"cn-hangzhou\\"}}"),
            ),
            tags={
                "Created": "TF",
                "For": "ServiceInstance",
            })
        ```

        ## Import

        Compute Nest Service Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:compute/nestServiceInstance:NestServiceInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['NestServiceInstanceCommodityArgs']] commodity: The order information of cloud market. See the following `Block commodity`.
        :param pulumi.Input[bool] enable_instance_ops: Whether the service instance has the O&M function. Default value: `false`. Valid values:
        :param pulumi.Input[bool] enable_user_prometheus: Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        :param pulumi.Input[pulumi.InputType['NestServiceInstanceOperationMetadataArgs']] operation_metadata: The configuration of O&M. See the following `Block operation_metadata`.
        :param pulumi.Input[str] parameters: The parameters entered by the deployment service instance.
        :param pulumi.Input[str] payment_type: The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] service_id: The ID of the service.
        :param pulumi.Input[str] service_instance_name: The name of the Service Instance.
        :param pulumi.Input[str] service_version: The version of the service.
        :param pulumi.Input[str] specification_name: The name of the specification.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] template_name: The name of the template.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NestServiceInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Compute Nest Service Instance resource.

        For information about Compute Nest Service Instance and how to use it, see [What is Service Instance](https://help.aliyun.com/document_detail/396194.html).

        > **NOTE:** Available in v1.205.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_resource_groups = alicloud.resourcemanager.get_resource_groups()
        default_zones = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_instance_types = alicloud.ecs.get_instance_types(availability_zone=default_zones.zones[0].id,
            instance_type_family="ecs.sn1ne")
        default_images = alicloud.ecs.get_images(name_regex="^ubuntu_[0-9]+_[0-9]+_x64*",
            most_recent=True,
            owners="system")
        default_networks = alicloud.vpc.get_networks(name_regex="your_name_regex")
        default_switches = alicloud.vpc.get_switches(vpc_id=default_networks.ids[0],
            zone_id=default_zones.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("defaultSecurityGroup", vpc_id=default_networks.ids[0])
        default_instance = alicloud.ecs.Instance("defaultInstance",
            image_id=default_images.images[0].id,
            instance_type=default_instance_types.instance_types[0].id,
            security_groups=[__item.id for __item in [default_security_group]],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=10,
            availability_zone=default_zones.zones[0].id,
            instance_charge_type="PostPaid",
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switches.ids[0])
        default_nest_service_instance = alicloud.compute.NestServiceInstance("defaultNestServiceInstance",
            service_id="service-dd475e6e468348799f0f",
            service_version="1",
            service_instance_name=var["name"],
            resource_group_id=default_resource_groups.groups[0].id,
            payment_type="Permanent",
            operation_metadata=alicloud.compute.NestServiceInstanceOperationMetadataArgs(
                operation_start_time="1681281179000",
                operation_end_time="1681367579000",
                resources=default_instance.id.apply(lambda id: f"{{\\"Type\\":\\"ResourceIds\\",\\"ResourceIds\\":{{\\"ALIYUN::ECS::INSTANCE\\":[\\"{id}\\"]}},\\"RegionId\\":\\"cn-hangzhou\\"}}"),
            ),
            tags={
                "Created": "TF",
                "For": "ServiceInstance",
            })
        ```

        ## Import

        Compute Nest Service Instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:compute/nestServiceInstance:NestServiceInstance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param NestServiceInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NestServiceInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 commodity: Optional[pulumi.Input[pulumi.InputType['NestServiceInstanceCommodityArgs']]] = None,
                 enable_instance_ops: Optional[pulumi.Input[bool]] = None,
                 enable_user_prometheus: Optional[pulumi.Input[bool]] = None,
                 operation_metadata: Optional[pulumi.Input[pulumi.InputType['NestServiceInstanceOperationMetadataArgs']]] = None,
                 parameters: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_instance_name: Optional[pulumi.Input[str]] = None,
                 service_version: Optional[pulumi.Input[str]] = None,
                 specification_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 template_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NestServiceInstanceArgs.__new__(NestServiceInstanceArgs)

            __props__.__dict__["commodity"] = commodity
            __props__.__dict__["enable_instance_ops"] = enable_instance_ops
            __props__.__dict__["enable_user_prometheus"] = enable_user_prometheus
            __props__.__dict__["operation_metadata"] = operation_metadata
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["resource_group_id"] = resource_group_id
            if service_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_id'")
            __props__.__dict__["service_id"] = service_id
            __props__.__dict__["service_instance_name"] = service_instance_name
            if service_version is None and not opts.urn:
                raise TypeError("Missing required property 'service_version'")
            __props__.__dict__["service_version"] = service_version
            __props__.__dict__["specification_name"] = specification_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["template_name"] = template_name
            __props__.__dict__["status"] = None
        super(NestServiceInstance, __self__).__init__(
            'alicloud:compute/nestServiceInstance:NestServiceInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            commodity: Optional[pulumi.Input[pulumi.InputType['NestServiceInstanceCommodityArgs']]] = None,
            enable_instance_ops: Optional[pulumi.Input[bool]] = None,
            enable_user_prometheus: Optional[pulumi.Input[bool]] = None,
            operation_metadata: Optional[pulumi.Input[pulumi.InputType['NestServiceInstanceOperationMetadataArgs']]] = None,
            parameters: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            service_id: Optional[pulumi.Input[str]] = None,
            service_instance_name: Optional[pulumi.Input[str]] = None,
            service_version: Optional[pulumi.Input[str]] = None,
            specification_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            template_name: Optional[pulumi.Input[str]] = None) -> 'NestServiceInstance':
        """
        Get an existing NestServiceInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['NestServiceInstanceCommodityArgs']] commodity: The order information of cloud market. See the following `Block commodity`.
        :param pulumi.Input[bool] enable_instance_ops: Whether the service instance has the O&M function. Default value: `false`. Valid values:
        :param pulumi.Input[bool] enable_user_prometheus: Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        :param pulumi.Input[pulumi.InputType['NestServiceInstanceOperationMetadataArgs']] operation_metadata: The configuration of O&M. See the following `Block operation_metadata`.
        :param pulumi.Input[str] parameters: The parameters entered by the deployment service instance.
        :param pulumi.Input[str] payment_type: The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] service_id: The ID of the service.
        :param pulumi.Input[str] service_instance_name: The name of the Service Instance.
        :param pulumi.Input[str] service_version: The version of the service.
        :param pulumi.Input[str] specification_name: The name of the specification.
        :param pulumi.Input[str] status: The status of the Service Instance.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] template_name: The name of the template.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NestServiceInstanceState.__new__(_NestServiceInstanceState)

        __props__.__dict__["commodity"] = commodity
        __props__.__dict__["enable_instance_ops"] = enable_instance_ops
        __props__.__dict__["enable_user_prometheus"] = enable_user_prometheus
        __props__.__dict__["operation_metadata"] = operation_metadata
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_instance_name"] = service_instance_name
        __props__.__dict__["service_version"] = service_version
        __props__.__dict__["specification_name"] = specification_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["template_name"] = template_name
        return NestServiceInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def commodity(self) -> pulumi.Output[Optional['outputs.NestServiceInstanceCommodity']]:
        """
        The order information of cloud market. See the following `Block commodity`.
        """
        return pulumi.get(self, "commodity")

    @property
    @pulumi.getter(name="enableInstanceOps")
    def enable_instance_ops(self) -> pulumi.Output[bool]:
        """
        Whether the service instance has the O&M function. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_instance_ops")

    @property
    @pulumi.getter(name="enableUserPrometheus")
    def enable_user_prometheus(self) -> pulumi.Output[bool]:
        """
        Whether Prometheus monitoring is enabled. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "enable_user_prometheus")

    @property
    @pulumi.getter(name="operationMetadata")
    def operation_metadata(self) -> pulumi.Output['outputs.NestServiceInstanceOperationMetadata']:
        """
        The configuration of O&M. See the following `Block operation_metadata`.
        """
        return pulumi.get(self, "operation_metadata")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[str]]:
        """
        The parameters entered by the deployment service instance.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The type of payment. Valid values: `Permanent`, `Subscription`, `PayAsYouGo`, `CustomFixTime`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[str]:
        """
        The ID of the service.
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceInstanceName")
    def service_instance_name(self) -> pulumi.Output[str]:
        """
        The name of the Service Instance.
        """
        return pulumi.get(self, "service_instance_name")

    @property
    @pulumi.getter(name="serviceVersion")
    def service_version(self) -> pulumi.Output[str]:
        """
        The version of the service.
        """
        return pulumi.get(self, "service_version")

    @property
    @pulumi.getter(name="specificationName")
    def specification_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the specification.
        """
        return pulumi.get(self, "specification_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the Service Instance.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> pulumi.Output[str]:
        """
        The name of the template.
        """
        return pulumi.get(self, "template_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['AccessLogArgs', 'AccessLog']

@pulumi.input_type
class AccessLogArgs:
    def __init__(__self__, *,
                 accelerator_id: pulumi.Input[str],
                 endpoint_group_id: pulumi.Input[str],
                 listener_id: pulumi.Input[str],
                 sls_log_store_name: pulumi.Input[str],
                 sls_project_name: pulumi.Input[str],
                 sls_region_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a AccessLog resource.
        :param pulumi.Input[str] accelerator_id: The ID of the global acceleration instance.
        :param pulumi.Input[str] endpoint_group_id: The ID of the endpoint group instance.
        :param pulumi.Input[str] listener_id: The ID of the listener.
        :param pulumi.Input[str] sls_log_store_name: The name of the Log Store.
        :param pulumi.Input[str] sls_project_name: The name of the Log Service project.
        :param pulumi.Input[str] sls_region_id: The region ID of the Log Service project.
        """
        pulumi.set(__self__, "accelerator_id", accelerator_id)
        pulumi.set(__self__, "endpoint_group_id", endpoint_group_id)
        pulumi.set(__self__, "listener_id", listener_id)
        pulumi.set(__self__, "sls_log_store_name", sls_log_store_name)
        pulumi.set(__self__, "sls_project_name", sls_project_name)
        pulumi.set(__self__, "sls_region_id", sls_region_id)

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> pulumi.Input[str]:
        """
        The ID of the global acceleration instance.
        """
        return pulumi.get(self, "accelerator_id")

    @accelerator_id.setter
    def accelerator_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "accelerator_id", value)

    @property
    @pulumi.getter(name="endpointGroupId")
    def endpoint_group_id(self) -> pulumi.Input[str]:
        """
        The ID of the endpoint group instance.
        """
        return pulumi.get(self, "endpoint_group_id")

    @endpoint_group_id.setter
    def endpoint_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "endpoint_group_id", value)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Input[str]:
        """
        The ID of the listener.
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter(name="slsLogStoreName")
    def sls_log_store_name(self) -> pulumi.Input[str]:
        """
        The name of the Log Store.
        """
        return pulumi.get(self, "sls_log_store_name")

    @sls_log_store_name.setter
    def sls_log_store_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "sls_log_store_name", value)

    @property
    @pulumi.getter(name="slsProjectName")
    def sls_project_name(self) -> pulumi.Input[str]:
        """
        The name of the Log Service project.
        """
        return pulumi.get(self, "sls_project_name")

    @sls_project_name.setter
    def sls_project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "sls_project_name", value)

    @property
    @pulumi.getter(name="slsRegionId")
    def sls_region_id(self) -> pulumi.Input[str]:
        """
        The region ID of the Log Service project.
        """
        return pulumi.get(self, "sls_region_id")

    @sls_region_id.setter
    def sls_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "sls_region_id", value)


@pulumi.input_type
class _AccessLogState:
    def __init__(__self__, *,
                 accelerator_id: Optional[pulumi.Input[str]] = None,
                 endpoint_group_id: Optional[pulumi.Input[str]] = None,
                 listener_id: Optional[pulumi.Input[str]] = None,
                 sls_log_store_name: Optional[pulumi.Input[str]] = None,
                 sls_project_name: Optional[pulumi.Input[str]] = None,
                 sls_region_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AccessLog resources.
        :param pulumi.Input[str] accelerator_id: The ID of the global acceleration instance.
        :param pulumi.Input[str] endpoint_group_id: The ID of the endpoint group instance.
        :param pulumi.Input[str] listener_id: The ID of the listener.
        :param pulumi.Input[str] sls_log_store_name: The name of the Log Store.
        :param pulumi.Input[str] sls_project_name: The name of the Log Service project.
        :param pulumi.Input[str] sls_region_id: The region ID of the Log Service project.
        :param pulumi.Input[str] status: Whether access log is enabled.
        """
        if accelerator_id is not None:
            pulumi.set(__self__, "accelerator_id", accelerator_id)
        if endpoint_group_id is not None:
            pulumi.set(__self__, "endpoint_group_id", endpoint_group_id)
        if listener_id is not None:
            pulumi.set(__self__, "listener_id", listener_id)
        if sls_log_store_name is not None:
            pulumi.set(__self__, "sls_log_store_name", sls_log_store_name)
        if sls_project_name is not None:
            pulumi.set(__self__, "sls_project_name", sls_project_name)
        if sls_region_id is not None:
            pulumi.set(__self__, "sls_region_id", sls_region_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the global acceleration instance.
        """
        return pulumi.get(self, "accelerator_id")

    @accelerator_id.setter
    def accelerator_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "accelerator_id", value)

    @property
    @pulumi.getter(name="endpointGroupId")
    def endpoint_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the endpoint group instance.
        """
        return pulumi.get(self, "endpoint_group_id")

    @endpoint_group_id.setter
    def endpoint_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_group_id", value)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the listener.
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter(name="slsLogStoreName")
    def sls_log_store_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Log Store.
        """
        return pulumi.get(self, "sls_log_store_name")

    @sls_log_store_name.setter
    def sls_log_store_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sls_log_store_name", value)

    @property
    @pulumi.getter(name="slsProjectName")
    def sls_project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Log Service project.
        """
        return pulumi.get(self, "sls_project_name")

    @sls_project_name.setter
    def sls_project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sls_project_name", value)

    @property
    @pulumi.getter(name="slsRegionId")
    def sls_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region ID of the Log Service project.
        """
        return pulumi.get(self, "sls_region_id")

    @sls_region_id.setter
    def sls_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sls_region_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Whether access log is enabled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class AccessLog(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accelerator_id: Optional[pulumi.Input[str]] = None,
                 endpoint_group_id: Optional[pulumi.Input[str]] = None,
                 listener_id: Optional[pulumi.Input[str]] = None,
                 sls_log_store_name: Optional[pulumi.Input[str]] = None,
                 sls_project_name: Optional[pulumi.Input[str]] = None,
                 sls_region_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Global Accelerator (GA) Access Log resource.

        For information about Global Accelerator (GA) Access Log and how to use it, see [What is Access Log](https://www.alibabacloud.com/help/en/global-accelerator/latest/api-ga-2019-11-20-attachlogstoretoendpointgroup).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        default_random_integer = random.RandomInteger("defaultRandomInteger",
            max=99999,
            min=10000)
        default_project = alicloud.log.Project("defaultProject")
        default_store = alicloud.log.Store("defaultStore", project=default_project.name)
        default_accelerator = alicloud.ga.Accelerator("defaultAccelerator",
            duration=1,
            auto_use_coupon=True,
            spec="2")
        default_bandwidth_package = alicloud.ga.BandwidthPackage("defaultBandwidthPackage",
            bandwidth=100,
            type="Basic",
            bandwidth_type="Basic",
            payment_type="PayAsYouGo",
            billing_type="PayBy95",
            ratio=30)
        default_bandwidth_package_attachment = alicloud.ga.BandwidthPackageAttachment("defaultBandwidthPackageAttachment",
            accelerator_id=default_accelerator.id,
            bandwidth_package_id=default_bandwidth_package.id)
        default_listener = alicloud.ga.Listener("defaultListener",
            accelerator_id=default_bandwidth_package_attachment.accelerator_id,
            client_affinity="SOURCE_IP",
            protocol="HTTP",
            port_ranges=[alicloud.ga.ListenerPortRangeArgs(
                from_port=70,
                to_port=70,
            )])
        default_eip_address = alicloud.ecs.EipAddress("defaultEipAddress",
            bandwidth="10",
            internet_charge_type="PayByBandwidth",
            address_name="terraform-example")
        default_endpoint_group = alicloud.ga.EndpointGroup("defaultEndpointGroup",
            accelerator_id=default_listener.accelerator_id,
            endpoint_configurations=[alicloud.ga.EndpointGroupEndpointConfigurationArgs(
                endpoint=default_eip_address.ip_address,
                type="PublicIp",
                weight=20,
            )],
            endpoint_group_region=region,
            listener_id=default_listener.id)
        default_access_log = alicloud.ga.AccessLog("defaultAccessLog",
            accelerator_id=default_accelerator.id,
            listener_id=default_listener.id,
            endpoint_group_id=default_endpoint_group.id,
            sls_project_name=default_project.name,
            sls_log_store_name=default_store.name,
            sls_region_id=region)
        ```

        ## Import

        Global Accelerator (GA) Access Log can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ga/accessLog:AccessLog example <accelerator_id>:<listener_id>:<endpoint_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accelerator_id: The ID of the global acceleration instance.
        :param pulumi.Input[str] endpoint_group_id: The ID of the endpoint group instance.
        :param pulumi.Input[str] listener_id: The ID of the listener.
        :param pulumi.Input[str] sls_log_store_name: The name of the Log Store.
        :param pulumi.Input[str] sls_project_name: The name of the Log Service project.
        :param pulumi.Input[str] sls_region_id: The region ID of the Log Service project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccessLogArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Global Accelerator (GA) Access Log resource.

        For information about Global Accelerator (GA) Access Log and how to use it, see [What is Access Log](https://www.alibabacloud.com/help/en/global-accelerator/latest/api-ga-2019-11-20-attachlogstoretoendpointgroup).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        default_random_integer = random.RandomInteger("defaultRandomInteger",
            max=99999,
            min=10000)
        default_project = alicloud.log.Project("defaultProject")
        default_store = alicloud.log.Store("defaultStore", project=default_project.name)
        default_accelerator = alicloud.ga.Accelerator("defaultAccelerator",
            duration=1,
            auto_use_coupon=True,
            spec="2")
        default_bandwidth_package = alicloud.ga.BandwidthPackage("defaultBandwidthPackage",
            bandwidth=100,
            type="Basic",
            bandwidth_type="Basic",
            payment_type="PayAsYouGo",
            billing_type="PayBy95",
            ratio=30)
        default_bandwidth_package_attachment = alicloud.ga.BandwidthPackageAttachment("defaultBandwidthPackageAttachment",
            accelerator_id=default_accelerator.id,
            bandwidth_package_id=default_bandwidth_package.id)
        default_listener = alicloud.ga.Listener("defaultListener",
            accelerator_id=default_bandwidth_package_attachment.accelerator_id,
            client_affinity="SOURCE_IP",
            protocol="HTTP",
            port_ranges=[alicloud.ga.ListenerPortRangeArgs(
                from_port=70,
                to_port=70,
            )])
        default_eip_address = alicloud.ecs.EipAddress("defaultEipAddress",
            bandwidth="10",
            internet_charge_type="PayByBandwidth",
            address_name="terraform-example")
        default_endpoint_group = alicloud.ga.EndpointGroup("defaultEndpointGroup",
            accelerator_id=default_listener.accelerator_id,
            endpoint_configurations=[alicloud.ga.EndpointGroupEndpointConfigurationArgs(
                endpoint=default_eip_address.ip_address,
                type="PublicIp",
                weight=20,
            )],
            endpoint_group_region=region,
            listener_id=default_listener.id)
        default_access_log = alicloud.ga.AccessLog("defaultAccessLog",
            accelerator_id=default_accelerator.id,
            listener_id=default_listener.id,
            endpoint_group_id=default_endpoint_group.id,
            sls_project_name=default_project.name,
            sls_log_store_name=default_store.name,
            sls_region_id=region)
        ```

        ## Import

        Global Accelerator (GA) Access Log can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ga/accessLog:AccessLog example <accelerator_id>:<listener_id>:<endpoint_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param AccessLogArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccessLogArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accelerator_id: Optional[pulumi.Input[str]] = None,
                 endpoint_group_id: Optional[pulumi.Input[str]] = None,
                 listener_id: Optional[pulumi.Input[str]] = None,
                 sls_log_store_name: Optional[pulumi.Input[str]] = None,
                 sls_project_name: Optional[pulumi.Input[str]] = None,
                 sls_region_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccessLogArgs.__new__(AccessLogArgs)

            if accelerator_id is None and not opts.urn:
                raise TypeError("Missing required property 'accelerator_id'")
            __props__.__dict__["accelerator_id"] = accelerator_id
            if endpoint_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'endpoint_group_id'")
            __props__.__dict__["endpoint_group_id"] = endpoint_group_id
            if listener_id is None and not opts.urn:
                raise TypeError("Missing required property 'listener_id'")
            __props__.__dict__["listener_id"] = listener_id
            if sls_log_store_name is None and not opts.urn:
                raise TypeError("Missing required property 'sls_log_store_name'")
            __props__.__dict__["sls_log_store_name"] = sls_log_store_name
            if sls_project_name is None and not opts.urn:
                raise TypeError("Missing required property 'sls_project_name'")
            __props__.__dict__["sls_project_name"] = sls_project_name
            if sls_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'sls_region_id'")
            __props__.__dict__["sls_region_id"] = sls_region_id
            __props__.__dict__["status"] = None
        super(AccessLog, __self__).__init__(
            'alicloud:ga/accessLog:AccessLog',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accelerator_id: Optional[pulumi.Input[str]] = None,
            endpoint_group_id: Optional[pulumi.Input[str]] = None,
            listener_id: Optional[pulumi.Input[str]] = None,
            sls_log_store_name: Optional[pulumi.Input[str]] = None,
            sls_project_name: Optional[pulumi.Input[str]] = None,
            sls_region_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'AccessLog':
        """
        Get an existing AccessLog resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accelerator_id: The ID of the global acceleration instance.
        :param pulumi.Input[str] endpoint_group_id: The ID of the endpoint group instance.
        :param pulumi.Input[str] listener_id: The ID of the listener.
        :param pulumi.Input[str] sls_log_store_name: The name of the Log Store.
        :param pulumi.Input[str] sls_project_name: The name of the Log Service project.
        :param pulumi.Input[str] sls_region_id: The region ID of the Log Service project.
        :param pulumi.Input[str] status: Whether access log is enabled.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccessLogState.__new__(_AccessLogState)

        __props__.__dict__["accelerator_id"] = accelerator_id
        __props__.__dict__["endpoint_group_id"] = endpoint_group_id
        __props__.__dict__["listener_id"] = listener_id
        __props__.__dict__["sls_log_store_name"] = sls_log_store_name
        __props__.__dict__["sls_project_name"] = sls_project_name
        __props__.__dict__["sls_region_id"] = sls_region_id
        __props__.__dict__["status"] = status
        return AccessLog(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> pulumi.Output[str]:
        """
        The ID of the global acceleration instance.
        """
        return pulumi.get(self, "accelerator_id")

    @property
    @pulumi.getter(name="endpointGroupId")
    def endpoint_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the endpoint group instance.
        """
        return pulumi.get(self, "endpoint_group_id")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Output[str]:
        """
        The ID of the listener.
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="slsLogStoreName")
    def sls_log_store_name(self) -> pulumi.Output[str]:
        """
        The name of the Log Store.
        """
        return pulumi.get(self, "sls_log_store_name")

    @property
    @pulumi.getter(name="slsProjectName")
    def sls_project_name(self) -> pulumi.Output[str]:
        """
        The name of the Log Service project.
        """
        return pulumi.get(self, "sls_project_name")

    @property
    @pulumi.getter(name="slsRegionId")
    def sls_region_id(self) -> pulumi.Output[str]:
        """
        The region ID of the Log Service project.
        """
        return pulumi.get(self, "sls_region_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Whether access log is enabled.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'AlertAnnotation',
    'AlertGroupConfiguration',
    'AlertJoinConfiguration',
    'AlertLabel',
    'AlertNotificationList',
    'AlertPolicyConfiguration',
    'AlertQueryList',
    'AlertSchedule',
    'AlertSeverityConfiguration',
    'AlertTemplateConfiguration',
    'EtlEtlSink',
    'OssExportConfigColumn',
    'OssShipperParquetConfig',
    'StoreEncryptConf',
    'StoreEncryptConfUserCmkInfo',
    'StoreIndexFieldSearch',
    'StoreIndexFieldSearchJsonKey',
    'StoreIndexFullText',
    'StoreShard',
    'GetProjectsProjectResult',
    'GetStoresStoreResult',
]

@pulumi.output_type
class AlertAnnotation(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Annotations's key for new alert.
        :param str value: Annotations's value for new alert.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Annotations's key for new alert.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Annotations's value for new alert.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class AlertGroupConfiguration(dict):
    def __init__(__self__, *,
                 type: str,
                 fields: Optional[Sequence[str]] = None):
        """
        :param str type: including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        pulumi.set(__self__, "type", type)
        if fields is not None:
            pulumi.set(__self__, "fields", fields)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def fields(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "fields")


@pulumi.output_type
class AlertJoinConfiguration(dict):
    def __init__(__self__, *,
                 condition: str,
                 type: str):
        """
        :param str condition: Join condition.
        :param str type: including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        pulumi.set(__self__, "condition", condition)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def condition(self) -> str:
        """
        Join condition.
        """
        return pulumi.get(self, "condition")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class AlertLabel(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Annotations's key for new alert.
        :param str value: Annotations's value for new alert.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Annotations's key for new alert.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Annotations's value for new alert.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class AlertNotificationList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "emailLists":
            suggest = "email_lists"
        elif key == "mobileLists":
            suggest = "mobile_lists"
        elif key == "serviceUri":
            suggest = "service_uri"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AlertNotificationList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AlertNotificationList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AlertNotificationList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 content: str,
                 type: str,
                 email_lists: Optional[Sequence[str]] = None,
                 mobile_lists: Optional[Sequence[str]] = None,
                 service_uri: Optional[str] = None):
        """
        :param str content: Notice content of alarm.
        :param str type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param Sequence[str] email_lists: Email address list.
        :param Sequence[str] mobile_lists: SMS sending mobile number.
        :param str service_uri: Request address.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "type", type)
        if email_lists is not None:
            pulumi.set(__self__, "email_lists", email_lists)
        if mobile_lists is not None:
            pulumi.set(__self__, "mobile_lists", mobile_lists)
        if service_uri is not None:
            pulumi.set(__self__, "service_uri", service_uri)

    @property
    @pulumi.getter
    def content(self) -> str:
        """
        Notice content of alarm.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="emailLists")
    def email_lists(self) -> Optional[Sequence[str]]:
        """
        Email address list.
        """
        return pulumi.get(self, "email_lists")

    @property
    @pulumi.getter(name="mobileLists")
    def mobile_lists(self) -> Optional[Sequence[str]]:
        """
        SMS sending mobile number.
        """
        return pulumi.get(self, "mobile_lists")

    @property
    @pulumi.getter(name="serviceUri")
    def service_uri(self) -> Optional[str]:
        """
        Request address.
        """
        return pulumi.get(self, "service_uri")


@pulumi.output_type
class AlertPolicyConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "alertPolicyId":
            suggest = "alert_policy_id"
        elif key == "repeatInterval":
            suggest = "repeat_interval"
        elif key == "actionPolicyId":
            suggest = "action_policy_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AlertPolicyConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AlertPolicyConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AlertPolicyConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 alert_policy_id: str,
                 repeat_interval: str,
                 action_policy_id: Optional[str] = None):
        """
        :param str alert_policy_id: Alert Policy Id.
        :param str repeat_interval: Repeat interval used by alert policy, 1h, 1m.e.g.
        :param str action_policy_id: Action Policy Id.
        """
        pulumi.set(__self__, "alert_policy_id", alert_policy_id)
        pulumi.set(__self__, "repeat_interval", repeat_interval)
        if action_policy_id is not None:
            pulumi.set(__self__, "action_policy_id", action_policy_id)

    @property
    @pulumi.getter(name="alertPolicyId")
    def alert_policy_id(self) -> str:
        """
        Alert Policy Id.
        """
        return pulumi.get(self, "alert_policy_id")

    @property
    @pulumi.getter(name="repeatInterval")
    def repeat_interval(self) -> str:
        """
        Repeat interval used by alert policy, 1h, 1m.e.g.
        """
        return pulumi.get(self, "repeat_interval")

    @property
    @pulumi.getter(name="actionPolicyId")
    def action_policy_id(self) -> Optional[str]:
        """
        Action Policy Id.
        """
        return pulumi.get(self, "action_policy_id")


@pulumi.output_type
class AlertQueryList(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "chartTitle":
            suggest = "chart_title"
        elif key == "dashboardId":
            suggest = "dashboard_id"
        elif key == "powerSqlMode":
            suggest = "power_sql_mode"
        elif key == "roleArn":
            suggest = "role_arn"
        elif key == "storeType":
            suggest = "store_type"
        elif key == "timeSpanType":
            suggest = "time_span_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AlertQueryList. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AlertQueryList.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AlertQueryList.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 end: str,
                 query: str,
                 start: str,
                 chart_title: Optional[str] = None,
                 dashboard_id: Optional[str] = None,
                 logstore: Optional[str] = None,
                 power_sql_mode: Optional[str] = None,
                 project: Optional[str] = None,
                 region: Optional[str] = None,
                 role_arn: Optional[str] = None,
                 store: Optional[str] = None,
                 store_type: Optional[str] = None,
                 time_span_type: Optional[str] = None):
        """
        :param str end: End time. example: 20s.
        :param str query: Query corresponding to chart. example: * AND aliyun.
        :param str start: Begin time. example: -60s.
        :param str chart_title: Chart title, optional from 1.161.0+.
        :param str dashboard_id: Query dashboard id.
        :param str logstore: Query logstore, use store for new alert, Deprecated from 1.161.0+.
        :param str power_sql_mode: default disable, whether to use power sql. support auto, enable, disable.
        :param str project: Query project.
        :param str region: Query project region.
        :param str role_arn: Query project store's ARN.
        :param str store: Query store for new alert.
        :param str store_type: Query store type for new alert, including log,metric,meta.
        :param str time_span_type: default Custom. No need to configure this parameter.
        """
        pulumi.set(__self__, "end", end)
        pulumi.set(__self__, "query", query)
        pulumi.set(__self__, "start", start)
        if chart_title is not None:
            pulumi.set(__self__, "chart_title", chart_title)
        if dashboard_id is not None:
            pulumi.set(__self__, "dashboard_id", dashboard_id)
        if logstore is not None:
            pulumi.set(__self__, "logstore", logstore)
        if power_sql_mode is not None:
            pulumi.set(__self__, "power_sql_mode", power_sql_mode)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if store is not None:
            pulumi.set(__self__, "store", store)
        if store_type is not None:
            pulumi.set(__self__, "store_type", store_type)
        if time_span_type is not None:
            pulumi.set(__self__, "time_span_type", time_span_type)

    @property
    @pulumi.getter
    def end(self) -> str:
        """
        End time. example: 20s.
        """
        return pulumi.get(self, "end")

    @property
    @pulumi.getter
    def query(self) -> str:
        """
        Query corresponding to chart. example: * AND aliyun.
        """
        return pulumi.get(self, "query")

    @property
    @pulumi.getter
    def start(self) -> str:
        """
        Begin time. example: -60s.
        """
        return pulumi.get(self, "start")

    @property
    @pulumi.getter(name="chartTitle")
    def chart_title(self) -> Optional[str]:
        """
        Chart title, optional from 1.161.0+.
        """
        return pulumi.get(self, "chart_title")

    @property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> Optional[str]:
        """
        Query dashboard id.
        """
        return pulumi.get(self, "dashboard_id")

    @property
    @pulumi.getter
    def logstore(self) -> Optional[str]:
        """
        Query logstore, use store for new alert, Deprecated from 1.161.0+.
        """
        warnings.warn("""Deprecated from 1.161.0+, use store""", DeprecationWarning)
        pulumi.log.warn("""logstore is deprecated: Deprecated from 1.161.0+, use store""")

        return pulumi.get(self, "logstore")

    @property
    @pulumi.getter(name="powerSqlMode")
    def power_sql_mode(self) -> Optional[str]:
        """
        default disable, whether to use power sql. support auto, enable, disable.
        """
        return pulumi.get(self, "power_sql_mode")

    @property
    @pulumi.getter
    def project(self) -> Optional[str]:
        """
        Query project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def region(self) -> Optional[str]:
        """
        Query project region.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[str]:
        """
        Query project store's ARN.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter
    def store(self) -> Optional[str]:
        """
        Query store for new alert.
        """
        return pulumi.get(self, "store")

    @property
    @pulumi.getter(name="storeType")
    def store_type(self) -> Optional[str]:
        """
        Query store type for new alert, including log,metric,meta.
        """
        return pulumi.get(self, "store_type")

    @property
    @pulumi.getter(name="timeSpanType")
    def time_span_type(self) -> Optional[str]:
        """
        default Custom. No need to configure this parameter.
        """
        return pulumi.get(self, "time_span_type")


@pulumi.output_type
class AlertSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cronExpression":
            suggest = "cron_expression"
        elif key == "dayOfWeek":
            suggest = "day_of_week"
        elif key == "runImmediately":
            suggest = "run_immediately"
        elif key == "timeZone":
            suggest = "time_zone"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AlertSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AlertSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AlertSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 cron_expression: Optional[str] = None,
                 day_of_week: Optional[int] = None,
                 delay: Optional[int] = None,
                 hour: Optional[int] = None,
                 interval: Optional[str] = None,
                 run_immediately: Optional[bool] = None,
                 time_zone: Optional[str] = None):
        """
        :param str type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param str cron_expression: Cron expression when type is Cron.
        :param int day_of_week: Day of week when type is Weekly, including 0,1,2,3,4,5,6, 0 for Sunday, 1 for Monday
        :param int hour: Hour of day when type is Weekly/Daily.
        :param str interval: Execution interval. 60 seconds minimum, such as 60s, 1h. used when type is FixedRate.
        :param str time_zone: Time zone for schedule.
        """
        pulumi.set(__self__, "type", type)
        if cron_expression is not None:
            pulumi.set(__self__, "cron_expression", cron_expression)
        if day_of_week is not None:
            pulumi.set(__self__, "day_of_week", day_of_week)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)
        if hour is not None:
            pulumi.set(__self__, "hour", hour)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if run_immediately is not None:
            pulumi.set(__self__, "run_immediately", run_immediately)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="cronExpression")
    def cron_expression(self) -> Optional[str]:
        """
        Cron expression when type is Cron.
        """
        return pulumi.get(self, "cron_expression")

    @property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> Optional[int]:
        """
        Day of week when type is Weekly, including 0,1,2,3,4,5,6, 0 for Sunday, 1 for Monday
        """
        return pulumi.get(self, "day_of_week")

    @property
    @pulumi.getter
    def delay(self) -> Optional[int]:
        return pulumi.get(self, "delay")

    @property
    @pulumi.getter
    def hour(self) -> Optional[int]:
        """
        Hour of day when type is Weekly/Daily.
        """
        return pulumi.get(self, "hour")

    @property
    @pulumi.getter
    def interval(self) -> Optional[str]:
        """
        Execution interval. 60 seconds minimum, such as 60s, 1h. used when type is FixedRate.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="runImmediately")
    def run_immediately(self) -> Optional[bool]:
        return pulumi.get(self, "run_immediately")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[str]:
        """
        Time zone for schedule.
        """
        return pulumi.get(self, "time_zone")


@pulumi.output_type
class AlertSeverityConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "evalCondition":
            suggest = "eval_condition"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AlertSeverityConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AlertSeverityConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AlertSeverityConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 eval_condition: Mapping[str, str],
                 severity: int):
        """
        :param Mapping[str, str] eval_condition: Severity when this condition is met.
        :param int severity: Severity for new alert, including 2,4,6,8,10 for Report,Low,Medium,High,Critical.
        """
        pulumi.set(__self__, "eval_condition", eval_condition)
        pulumi.set(__self__, "severity", severity)

    @property
    @pulumi.getter(name="evalCondition")
    def eval_condition(self) -> Mapping[str, str]:
        """
        Severity when this condition is met.
        """
        return pulumi.get(self, "eval_condition")

    @property
    @pulumi.getter
    def severity(self) -> int:
        """
        Severity for new alert, including 2,4,6,8,10 for Report,Low,Medium,High,Critical.
        """
        return pulumi.get(self, "severity")


@pulumi.output_type
class AlertTemplateConfiguration(dict):
    def __init__(__self__, *,
                 id: str,
                 type: str,
                 annotations: Optional[Mapping[str, str]] = None,
                 lang: Optional[str] = None,
                 tokens: Optional[Mapping[str, str]] = None):
        """
        :param str id: Alert template id.
        :param str type: including FixedRate,Hourly,Daily,Weekly,Cron.
        :param Mapping[str, str] annotations: Alert template annotations.
        :param str lang: Alert template language including `cn`, `en`.
        :param Mapping[str, str] tokens: Alert template tokens.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "type", type)
        if annotations is not None:
            pulumi.set(__self__, "annotations", annotations)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if tokens is not None:
            pulumi.set(__self__, "tokens", tokens)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Alert template id.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        including FixedRate,Hourly,Daily,Weekly,Cron.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def annotations(self) -> Optional[Mapping[str, str]]:
        """
        Alert template annotations.
        """
        return pulumi.get(self, "annotations")

    @property
    @pulumi.getter
    def lang(self) -> Optional[str]:
        """
        Alert template language including `cn`, `en`.
        """
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter
    def tokens(self) -> Optional[Mapping[str, str]]:
        """
        Alert template tokens.
        """
        return pulumi.get(self, "tokens")


@pulumi.output_type
class EtlEtlSink(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessKeyId":
            suggest = "access_key_id"
        elif key == "accessKeySecret":
            suggest = "access_key_secret"
        elif key == "kmsEncryptedAccessKeyId":
            suggest = "kms_encrypted_access_key_id"
        elif key == "kmsEncryptedAccessKeySecret":
            suggest = "kms_encrypted_access_key_secret"
        elif key == "roleArn":
            suggest = "role_arn"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EtlEtlSink. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EtlEtlSink.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EtlEtlSink.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 endpoint: str,
                 logstore: str,
                 name: str,
                 project: str,
                 access_key_id: Optional[str] = None,
                 access_key_secret: Optional[str] = None,
                 kms_encrypted_access_key_id: Optional[str] = None,
                 kms_encrypted_access_key_secret: Optional[str] = None,
                 role_arn: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str endpoint: Delivery target logstore region.
        :param str logstore: Delivery target logstore.
        :param str name: Delivery target name.
        :param str project: The project where the target logstore is delivered.
        :param str access_key_id: Delivery target logstore access key id.
        :param str access_key_secret: Delivery target logstore access key secret.
        :param str kms_encrypted_access_key_id: An KMS encrypts access key id used to a log etl job. If the `access_key_id` is filled in, this field will be ignored.
        :param str kms_encrypted_access_key_secret: An KMS encrypts access key secret used to a log etl job. If the `access_key_secret` is filled in, this field will be ignored.
        :param str role_arn: Sts role info under delivery target logstore. `role_arn` and `(access_key_id, access_key_secret)` fill in at most one. If you do not fill in both, then you must fill in `(kms_encrypted_access_key_id, kms_encrypted_access_key_secret, kms_encryption_access_key_id_context, kms_encryption_access_key_secret_context)` to use KMS to get the key pair.
        :param str type: ETL sinks type, the default value is AliyunLOG.
               
               > **Note:** `from_time` and `to_time` no modification allowed after successful creation.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "logstore", logstore)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "project", project)
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if access_key_secret is not None:
            pulumi.set(__self__, "access_key_secret", access_key_secret)
        if kms_encrypted_access_key_id is not None:
            pulumi.set(__self__, "kms_encrypted_access_key_id", kms_encrypted_access_key_id)
        if kms_encrypted_access_key_secret is not None:
            pulumi.set(__self__, "kms_encrypted_access_key_secret", kms_encrypted_access_key_secret)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def endpoint(self) -> str:
        """
        Delivery target logstore region.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter
    def logstore(self) -> str:
        """
        Delivery target logstore.
        """
        return pulumi.get(self, "logstore")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Delivery target name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The project where the target logstore is delivered.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[str]:
        """
        Delivery target logstore access key id.
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="accessKeySecret")
    def access_key_secret(self) -> Optional[str]:
        """
        Delivery target logstore access key secret.
        """
        return pulumi.get(self, "access_key_secret")

    @property
    @pulumi.getter(name="kmsEncryptedAccessKeyId")
    def kms_encrypted_access_key_id(self) -> Optional[str]:
        """
        An KMS encrypts access key id used to a log etl job. If the `access_key_id` is filled in, this field will be ignored.
        """
        return pulumi.get(self, "kms_encrypted_access_key_id")

    @property
    @pulumi.getter(name="kmsEncryptedAccessKeySecret")
    def kms_encrypted_access_key_secret(self) -> Optional[str]:
        """
        An KMS encrypts access key secret used to a log etl job. If the `access_key_secret` is filled in, this field will be ignored.
        """
        return pulumi.get(self, "kms_encrypted_access_key_secret")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[str]:
        """
        Sts role info under delivery target logstore. `role_arn` and `(access_key_id, access_key_secret)` fill in at most one. If you do not fill in both, then you must fill in `(kms_encrypted_access_key_id, kms_encrypted_access_key_secret, kms_encryption_access_key_id_context, kms_encryption_access_key_secret_context)` to use KMS to get the key pair.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        ETL sinks type, the default value is AliyunLOG.

        > **Note:** `from_time` and `to_time` no modification allowed after successful creation.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class OssExportConfigColumn(dict):
    def __init__(__self__, *,
                 name: str,
                 type: str):
        """
        :param str name: The name of the key.
        :param str type: Type of configuration name.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Type of configuration name.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class OssShipperParquetConfig(dict):
    def __init__(__self__, *,
                 name: str,
                 type: str):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")


@pulumi.output_type
class StoreEncryptConf(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "encryptType":
            suggest = "encrypt_type"
        elif key == "userCmkInfo":
            suggest = "user_cmk_info"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StoreEncryptConf. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StoreEncryptConf.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StoreEncryptConf.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enable: Optional[bool] = None,
                 encrypt_type: Optional[str] = None,
                 user_cmk_info: Optional['outputs.StoreEncryptConfUserCmkInfo'] = None):
        """
        :param bool enable: enable encryption. Default `false`
        :param str encrypt_type: Supported encryption type, only supports `default(AES)`,` m4`
        :param 'StoreEncryptConfUserCmkInfoArgs' user_cmk_info: User bring your own key (BYOK) encryption [Refer to details](https://www.alibabacloud.com/help/zh/doc-detail/187853.htm), the format is as follows:
               
               ```python
               import pulumi
               ```
               #### Block user_cmk_info
        """
        if enable is not None:
            pulumi.set(__self__, "enable", enable)
        if encrypt_type is not None:
            pulumi.set(__self__, "encrypt_type", encrypt_type)
        if user_cmk_info is not None:
            pulumi.set(__self__, "user_cmk_info", user_cmk_info)

    @property
    @pulumi.getter
    def enable(self) -> Optional[bool]:
        """
        enable encryption. Default `false`
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter(name="encryptType")
    def encrypt_type(self) -> Optional[str]:
        """
        Supported encryption type, only supports `default(AES)`,` m4`
        """
        return pulumi.get(self, "encrypt_type")

    @property
    @pulumi.getter(name="userCmkInfo")
    def user_cmk_info(self) -> Optional['outputs.StoreEncryptConfUserCmkInfo']:
        """
        User bring your own key (BYOK) encryption [Refer to details](https://www.alibabacloud.com/help/zh/doc-detail/187853.htm), the format is as follows:

        ```python
        import pulumi
        ```
        #### Block user_cmk_info
        """
        return pulumi.get(self, "user_cmk_info")


@pulumi.output_type
class StoreEncryptConfUserCmkInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cmkKeyId":
            suggest = "cmk_key_id"
        elif key == "regionId":
            suggest = "region_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StoreEncryptConfUserCmkInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StoreEncryptConfUserCmkInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StoreEncryptConfUserCmkInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 arn: str,
                 cmk_key_id: str,
                 region_id: str):
        """
        :param str arn: role arn.
        :param str cmk_key_id: User master key id.
        :param str region_id: Region id where the  user master key id is located.
        """
        pulumi.set(__self__, "arn", arn)
        pulumi.set(__self__, "cmk_key_id", cmk_key_id)
        pulumi.set(__self__, "region_id", region_id)

    @property
    @pulumi.getter
    def arn(self) -> str:
        """
        role arn.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="cmkKeyId")
    def cmk_key_id(self) -> str:
        """
        User master key id.
        """
        return pulumi.get(self, "cmk_key_id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        """
        Region id where the  user master key id is located.
        """
        return pulumi.get(self, "region_id")


@pulumi.output_type
class StoreIndexFieldSearch(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "caseSensitive":
            suggest = "case_sensitive"
        elif key == "enableAnalytics":
            suggest = "enable_analytics"
        elif key == "includeChinese":
            suggest = "include_chinese"
        elif key == "jsonKeys":
            suggest = "json_keys"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StoreIndexFieldSearch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StoreIndexFieldSearch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StoreIndexFieldSearch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 alias: Optional[str] = None,
                 case_sensitive: Optional[bool] = None,
                 enable_analytics: Optional[bool] = None,
                 include_chinese: Optional[bool] = None,
                 json_keys: Optional[Sequence['outputs.StoreIndexFieldSearchJsonKey']] = None,
                 token: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str name: When using the json_keys field, this field is required.
        :param str alias: The alias of one field.
        :param bool case_sensitive: Whether the case sensitive for the field. Default to false. It is valid when "type" is "text" or "json".
        :param bool enable_analytics: Whether to enable field analytics. Default to true.
        :param bool include_chinese: Whether includes the chinese for the field. Default to false. It is valid when "type" is "text" or "json".
        :param Sequence['StoreIndexFieldSearchJsonKeyArgs'] json_keys: Use nested index when type is json
        :param str token: The string of several split words, like "\\r", "#". It is valid when "type" is "text" or "json".
        :param str type: The type of one field. Valid values: ["long", "text", "double"]. Default to "long"
        """
        pulumi.set(__self__, "name", name)
        if alias is not None:
            pulumi.set(__self__, "alias", alias)
        if case_sensitive is not None:
            pulumi.set(__self__, "case_sensitive", case_sensitive)
        if enable_analytics is not None:
            pulumi.set(__self__, "enable_analytics", enable_analytics)
        if include_chinese is not None:
            pulumi.set(__self__, "include_chinese", include_chinese)
        if json_keys is not None:
            pulumi.set(__self__, "json_keys", json_keys)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        When using the json_keys field, this field is required.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def alias(self) -> Optional[str]:
        """
        The alias of one field.
        """
        return pulumi.get(self, "alias")

    @property
    @pulumi.getter(name="caseSensitive")
    def case_sensitive(self) -> Optional[bool]:
        """
        Whether the case sensitive for the field. Default to false. It is valid when "type" is "text" or "json".
        """
        return pulumi.get(self, "case_sensitive")

    @property
    @pulumi.getter(name="enableAnalytics")
    def enable_analytics(self) -> Optional[bool]:
        """
        Whether to enable field analytics. Default to true.
        """
        return pulumi.get(self, "enable_analytics")

    @property
    @pulumi.getter(name="includeChinese")
    def include_chinese(self) -> Optional[bool]:
        """
        Whether includes the chinese for the field. Default to false. It is valid when "type" is "text" or "json".
        """
        return pulumi.get(self, "include_chinese")

    @property
    @pulumi.getter(name="jsonKeys")
    def json_keys(self) -> Optional[Sequence['outputs.StoreIndexFieldSearchJsonKey']]:
        """
        Use nested index when type is json
        """
        return pulumi.get(self, "json_keys")

    @property
    @pulumi.getter
    def token(self) -> Optional[str]:
        """
        The string of several split words, like "\\r", "#". It is valid when "type" is "text" or "json".
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        The type of one field. Valid values: ["long", "text", "double"]. Default to "long"
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class StoreIndexFieldSearchJsonKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "docValue":
            suggest = "doc_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StoreIndexFieldSearchJsonKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StoreIndexFieldSearchJsonKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StoreIndexFieldSearchJsonKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 alias: Optional[str] = None,
                 doc_value: Optional[bool] = None,
                 type: Optional[str] = None):
        """
        :param str name: When using the json_keys field, this field is required.
        :param str alias: The alias of one field.
        :param bool doc_value: Whether to enable statistics. default to true.
               
               > **Note:** At least one of the "full_text" and "field_search" should be specified.
        :param str type: The type of one field. Valid values: ["long", "text", "double"]. Default to "long"
        """
        pulumi.set(__self__, "name", name)
        if alias is not None:
            pulumi.set(__self__, "alias", alias)
        if doc_value is not None:
            pulumi.set(__self__, "doc_value", doc_value)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        When using the json_keys field, this field is required.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def alias(self) -> Optional[str]:
        """
        The alias of one field.
        """
        return pulumi.get(self, "alias")

    @property
    @pulumi.getter(name="docValue")
    def doc_value(self) -> Optional[bool]:
        """
        Whether to enable statistics. default to true.

        > **Note:** At least one of the "full_text" and "field_search" should be specified.
        """
        return pulumi.get(self, "doc_value")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        The type of one field. Valid values: ["long", "text", "double"]. Default to "long"
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class StoreIndexFullText(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "caseSensitive":
            suggest = "case_sensitive"
        elif key == "includeChinese":
            suggest = "include_chinese"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StoreIndexFullText. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StoreIndexFullText.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StoreIndexFullText.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 case_sensitive: Optional[bool] = None,
                 include_chinese: Optional[bool] = None,
                 token: Optional[str] = None):
        """
        :param bool case_sensitive: Whether the case sensitive for the field. Default to false. It is valid when "type" is "text" or "json".
        :param bool include_chinese: Whether includes the chinese for the field. Default to false. It is valid when "type" is "text" or "json".
        :param str token: The string of several split words, like "\\r", "#". It is valid when "type" is "text" or "json".
        """
        if case_sensitive is not None:
            pulumi.set(__self__, "case_sensitive", case_sensitive)
        if include_chinese is not None:
            pulumi.set(__self__, "include_chinese", include_chinese)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter(name="caseSensitive")
    def case_sensitive(self) -> Optional[bool]:
        """
        Whether the case sensitive for the field. Default to false. It is valid when "type" is "text" or "json".
        """
        return pulumi.get(self, "case_sensitive")

    @property
    @pulumi.getter(name="includeChinese")
    def include_chinese(self) -> Optional[bool]:
        """
        Whether includes the chinese for the field. Default to false. It is valid when "type" is "text" or "json".
        """
        return pulumi.get(self, "include_chinese")

    @property
    @pulumi.getter
    def token(self) -> Optional[str]:
        """
        The string of several split words, like "\\r", "#". It is valid when "type" is "text" or "json".
        """
        return pulumi.get(self, "token")


@pulumi.output_type
class StoreShard(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "beginKey":
            suggest = "begin_key"
        elif key == "endKey":
            suggest = "end_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in StoreShard. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        StoreShard.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        StoreShard.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 begin_key: Optional[str] = None,
                 end_key: Optional[str] = None,
                 id: Optional[int] = None,
                 status: Optional[str] = None):
        """
        :param str begin_key: The begin value of the shard range(MD5), included in the shard range.
        :param str end_key: The end value of the shard range(MD5), not included in shard range.
        :param int id: The ID of the shard.
        :param str status: Shard status, only two status of `readwrite` and `readonly`.
        """
        if begin_key is not None:
            pulumi.set(__self__, "begin_key", begin_key)
        if end_key is not None:
            pulumi.set(__self__, "end_key", end_key)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="beginKey")
    def begin_key(self) -> Optional[str]:
        """
        The begin value of the shard range(MD5), included in the shard range.
        """
        return pulumi.get(self, "begin_key")

    @property
    @pulumi.getter(name="endKey")
    def end_key(self) -> Optional[str]:
        """
        The end value of the shard range(MD5), not included in shard range.
        """
        return pulumi.get(self, "end_key")

    @property
    @pulumi.getter
    def id(self) -> Optional[int]:
        """
        The ID of the shard.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        Shard status, only two status of `readwrite` and `readonly`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetProjectsProjectResult(dict):
    def __init__(__self__, *,
                 description: str,
                 id: str,
                 last_modify_time: str,
                 owner: str,
                 policy: str,
                 project_name: str,
                 region: str,
                 status: str):
        """
        :param str description: The description of the project.
        :param str id: The ID of the project.
        :param str last_modify_time: The last modify time of project.
        :param str owner: The owner of project.
        :param str policy: The policy of project.
        :param str project_name: The name of the project.
        :param str region: The region of project.
        :param str status: The status of project.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_modify_time", last_modify_time)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the project.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the project.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastModifyTime")
    def last_modify_time(self) -> str:
        """
        The last modify time of project.
        """
        return pulumi.get(self, "last_modify_time")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        The owner of project.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def policy(self) -> str:
        """
        The policy of project.
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        The name of the project.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region of project.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of project.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetStoresStoreResult(dict):
    def __init__(__self__, *,
                 id: str,
                 store_name: str):
        """
        :param str id: The ID of the store.
        :param str store_name: The name of the store.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "store_name", store_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the store.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="storeName")
    def store_name(self) -> str:
        """
        The name of the store.
        """
        return pulumi.get(self, "store_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAccessGroupsGroupResult',
    'GetAccessRulesRuleResult',
    'GetFileSystemsSystemResult',
    'GetMountPointsPointResult',
    'GetZonesZoneResult',
    'GetZonesZoneOptionResult',
]

@pulumi.output_type
class GetAccessGroupsGroupResult(dict):
    def __init__(__self__, *,
                 access_group_id: str,
                 access_group_name: str,
                 create_time: str,
                 description: str,
                 id: str,
                 mount_point_count: int,
                 network_type: str,
                 rule_count: int):
        """
        :param str access_group_id: The length of `description` does not exceed 100 bytes.
        :param str access_group_name: The Name of Access Group. The length Of `access_group_name` does not exceed 100 bytes.
        :param str create_time: The CreateTime of Access Group.
        :param str description: The Description of Access Group. The length Of `description` does not exceed 100 bytes.
        :param str id: The ID of the Access Group.
        :param int mount_point_count: The Number of attached mountpoint.
        :param str network_type: The NetworkType of Access Group. Valid values: `VPC`.
        :param int rule_count: The Number of access rule.
        """
        pulumi.set(__self__, "access_group_id", access_group_id)
        pulumi.set(__self__, "access_group_name", access_group_name)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mount_point_count", mount_point_count)
        pulumi.set(__self__, "network_type", network_type)
        pulumi.set(__self__, "rule_count", rule_count)

    @property
    @pulumi.getter(name="accessGroupId")
    def access_group_id(self) -> str:
        """
        The length of `description` does not exceed 100 bytes.
        """
        return pulumi.get(self, "access_group_id")

    @property
    @pulumi.getter(name="accessGroupName")
    def access_group_name(self) -> str:
        """
        The Name of Access Group. The length Of `access_group_name` does not exceed 100 bytes.
        """
        return pulumi.get(self, "access_group_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The CreateTime of Access Group.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The Description of Access Group. The length Of `description` does not exceed 100 bytes.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mountPointCount")
    def mount_point_count(self) -> int:
        """
        The Number of attached mountpoint.
        """
        return pulumi.get(self, "mount_point_count")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> str:
        """
        The NetworkType of Access Group. Valid values: `VPC`.
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="ruleCount")
    def rule_count(self) -> int:
        """
        The Number of access rule.
        """
        return pulumi.get(self, "rule_count")


@pulumi.output_type
class GetAccessRulesRuleResult(dict):
    def __init__(__self__, *,
                 access_group_id: str,
                 access_rule_id: str,
                 create_time: str,
                 description: str,
                 id: str,
                 network_segment: str,
                 priority: int,
                 rw_access_type: str):
        """
        :param str access_group_id: The resource ID of the Access Group.
        :param str access_rule_id: The ID of the Access Rule.
        :param str create_time: The created time of the Access Rule.
        :param str description: The description of the Access Rule.
        :param str id: The resource ID of Access Rule.
        :param str network_segment: The NetworkSegment of the Access Rule.
        :param int priority: The priority of the Access Rule.
        :param str rw_access_type: RWAccessType of the Access Rule. Valid values: `RDONLY`, `RDWR`.
        """
        pulumi.set(__self__, "access_group_id", access_group_id)
        pulumi.set(__self__, "access_rule_id", access_rule_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "network_segment", network_segment)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "rw_access_type", rw_access_type)

    @property
    @pulumi.getter(name="accessGroupId")
    def access_group_id(self) -> str:
        """
        The resource ID of the Access Group.
        """
        return pulumi.get(self, "access_group_id")

    @property
    @pulumi.getter(name="accessRuleId")
    def access_rule_id(self) -> str:
        """
        The ID of the Access Rule.
        """
        return pulumi.get(self, "access_rule_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The created time of the Access Rule.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the Access Rule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The resource ID of Access Rule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="networkSegment")
    def network_segment(self) -> str:
        """
        The NetworkSegment of the Access Rule.
        """
        return pulumi.get(self, "network_segment")

    @property
    @pulumi.getter
    def priority(self) -> int:
        """
        The priority of the Access Rule.
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="rwAccessType")
    def rw_access_type(self) -> str:
        """
        RWAccessType of the Access Rule. Valid values: `RDONLY`, `RDWR`.
        """
        return pulumi.get(self, "rw_access_type")


@pulumi.output_type
class GetFileSystemsSystemResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 description: str,
                 file_system_id: str,
                 file_system_name: str,
                 id: str,
                 mount_point_count: int,
                 number_of_directories: int,
                 number_of_files: int,
                 protocol_type: str,
                 provisioned_throughput_in_mi_bps: int,
                 space_capacity: int,
                 storage_package_id: str,
                 storage_type: str,
                 throughput_mode: str,
                 used_space_size: float,
                 zone_id: str):
        """
        :param str create_time: The creation time of the File system.
        :param str description: The description of the File system.
        :param str file_system_id: The ID of the File System.
        :param str file_system_name: The name of the File system.
        :param str id: The ID of the File System.
        :param int mount_point_count: The number of Mount points.
        :param int number_of_directories: The number of directories.
        :param int number_of_files: The number of files.
        :param str protocol_type: The protocol type. Valid values: `HDFS`.
        :param int provisioned_throughput_in_mi_bps: The preset throughput of the File system. Valid values: `1` to `1024`, Unit: MB/s.
        :param int space_capacity: The capacity budget of the File system.
        :param str storage_package_id: Storage package Id.
        :param str storage_type: The storage specifications of the File system. Valid values: `PERFORMANCE`, `STANDARD`.
        :param str throughput_mode: The throughput mode of the File system. Valid values: `Provisioned`, `Standard`.
        :param float used_space_size: The used space of the File system.
        :param str zone_id: The zone ID of the File system.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "file_system_name", file_system_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mount_point_count", mount_point_count)
        pulumi.set(__self__, "number_of_directories", number_of_directories)
        pulumi.set(__self__, "number_of_files", number_of_files)
        pulumi.set(__self__, "protocol_type", protocol_type)
        pulumi.set(__self__, "provisioned_throughput_in_mi_bps", provisioned_throughput_in_mi_bps)
        pulumi.set(__self__, "space_capacity", space_capacity)
        pulumi.set(__self__, "storage_package_id", storage_package_id)
        pulumi.set(__self__, "storage_type", storage_type)
        pulumi.set(__self__, "throughput_mode", throughput_mode)
        pulumi.set(__self__, "used_space_size", used_space_size)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the File system.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the File system.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> str:
        """
        The ID of the File System.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> str:
        """
        The name of the File system.
        """
        return pulumi.get(self, "file_system_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the File System.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mountPointCount")
    def mount_point_count(self) -> int:
        """
        The number of Mount points.
        """
        return pulumi.get(self, "mount_point_count")

    @property
    @pulumi.getter(name="numberOfDirectories")
    def number_of_directories(self) -> int:
        """
        The number of directories.
        """
        return pulumi.get(self, "number_of_directories")

    @property
    @pulumi.getter(name="numberOfFiles")
    def number_of_files(self) -> int:
        """
        The number of files.
        """
        return pulumi.get(self, "number_of_files")

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> str:
        """
        The protocol type. Valid values: `HDFS`.
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="provisionedThroughputInMiBps")
    def provisioned_throughput_in_mi_bps(self) -> int:
        """
        The preset throughput of the File system. Valid values: `1` to `1024`, Unit: MB/s.
        """
        return pulumi.get(self, "provisioned_throughput_in_mi_bps")

    @property
    @pulumi.getter(name="spaceCapacity")
    def space_capacity(self) -> int:
        """
        The capacity budget of the File system.
        """
        return pulumi.get(self, "space_capacity")

    @property
    @pulumi.getter(name="storagePackageId")
    def storage_package_id(self) -> str:
        """
        Storage package Id.
        """
        return pulumi.get(self, "storage_package_id")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> str:
        """
        The storage specifications of the File system. Valid values: `PERFORMANCE`, `STANDARD`.
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="throughputMode")
    def throughput_mode(self) -> str:
        """
        The throughput mode of the File system. Valid values: `Provisioned`, `Standard`.
        """
        return pulumi.get(self, "throughput_mode")

    @property
    @pulumi.getter(name="usedSpaceSize")
    def used_space_size(self) -> float:
        """
        The used space of the File system.
        """
        return pulumi.get(self, "used_space_size")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The zone ID of the File system.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetMountPointsPointResult(dict):
    def __init__(__self__, *,
                 access_group_id: str,
                 create_time: str,
                 description: str,
                 file_system_id: str,
                 id: str,
                 mount_point_domain: str,
                 mount_point_id: str,
                 network_type: str,
                 status: str,
                 vpc_id: str,
                 vswitch_id: str):
        """
        :param str access_group_id: The ID of the Access Group.
        :param str create_time: The created time of the Mount Point.
        :param str description: The description of the Mount Point.
        :param str file_system_id: The ID of the File System.
        :param str id: The ID of the Mount Point.
        :param str mount_point_domain: The domain name of the Mount Point.
        :param str mount_point_id: The ID of the Mount Point.
        :param str network_type: The network type of the Mount Point. Valid values: `VPC`.
        :param str status: The status of the Mount Point. Valid values: `Active`, `Inactive`.
        :param str vpc_id: The ID of the VPC network.
        :param str vswitch_id: The vswitch id.
        """
        pulumi.set(__self__, "access_group_id", access_group_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mount_point_domain", mount_point_domain)
        pulumi.set(__self__, "mount_point_id", mount_point_id)
        pulumi.set(__self__, "network_type", network_type)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="accessGroupId")
    def access_group_id(self) -> str:
        """
        The ID of the Access Group.
        """
        return pulumi.get(self, "access_group_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The created time of the Mount Point.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the Mount Point.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> str:
        """
        The ID of the File System.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Mount Point.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mountPointDomain")
    def mount_point_domain(self) -> str:
        """
        The domain name of the Mount Point.
        """
        return pulumi.get(self, "mount_point_domain")

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> str:
        """
        The ID of the Mount Point.
        """
        return pulumi.get(self, "mount_point_id")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> str:
        """
        The network type of the Mount Point. Valid values: `VPC`.
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the Mount Point. Valid values: `Active`, `Inactive`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The ID of the VPC network.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> str:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")


@pulumi.output_type
class GetZonesZoneResult(dict):
    def __init__(__self__, *,
                 options: Sequence['outputs.GetZonesZoneOptionResult'],
                 zone_id: str):
        """
        :param Sequence['GetZonesZoneOptionArgs'] options: A list of available configurations of the Zone.
        :param str zone_id: The zone ID.
        """
        pulumi.set(__self__, "options", options)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def options(self) -> Sequence['outputs.GetZonesZoneOptionResult']:
        """
        A list of available configurations of the Zone.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetZonesZoneOptionResult(dict):
    def __init__(__self__, *,
                 protocol_type: str,
                 storage_type: str):
        """
        :param str protocol_type: The protocol type. Valid values: `HDFS`.
        :param str storage_type: The storage specifications of the File system. Valid values: `PERFORMANCE`, `STANDARD`.
        """
        pulumi.set(__self__, "protocol_type", protocol_type)
        pulumi.set(__self__, "storage_type", storage_type)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> str:
        """
        The protocol type. Valid values: `HDFS`.
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> str:
        """
        The storage specifications of the File system. Valid values: `PERFORMANCE`, `STANDARD`.
        """
        return pulumi.get(self, "storage_type")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetActivationsResult',
    'AwaitableGetActivationsResult',
    'get_activations',
    'get_activations_output',
]

@pulumi.output_type
class GetActivationsResult:
    """
    A collection of values returned by getActivations.
    """
    def __init__(__self__, activations=None, id=None, ids=None, instance_name=None, output_file=None, page_number=None, page_size=None, total_count=None):
        if activations and not isinstance(activations, list):
            raise TypeError("Expected argument 'activations' to be a list")
        pulumi.set(__self__, "activations", activations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if total_count and not isinstance(total_count, int):
            raise TypeError("Expected argument 'total_count' to be a int")
        pulumi.set(__self__, "total_count", total_count)

    @property
    @pulumi.getter
    def activations(self) -> Sequence['outputs.GetActivationsActivationResult']:
        return pulumi.get(self, "activations")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[str]:
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="totalCount")
    def total_count(self) -> int:
        return pulumi.get(self, "total_count")


class AwaitableGetActivationsResult(GetActivationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetActivationsResult(
            activations=self.activations,
            id=self.id,
            ids=self.ids,
            instance_name=self.instance_name,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            total_count=self.total_count)


def get_activations(ids: Optional[Sequence[str]] = None,
                    instance_name: Optional[str] = None,
                    output_file: Optional[str] = None,
                    page_number: Optional[int] = None,
                    page_size: Optional[int] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetActivationsResult:
    """
    This data source provides the Ecs Activations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.177.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ecs.get_activations()
    pulumi.export("ecsActivationId1", ids.activations[0].id)
    ```


    :param Sequence[str] ids: A list of Activation IDs.
    :param str instance_name: The default prefix of the instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['instanceName'] = instance_name
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ecs/getActivations:getActivations', __args__, opts=opts, typ=GetActivationsResult).value

    return AwaitableGetActivationsResult(
        activations=pulumi.get(__ret__, 'activations'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        total_count=pulumi.get(__ret__, 'total_count'))


@_utilities.lift_output_func(get_activations)
def get_activations_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                           instance_name: Optional[pulumi.Input[Optional[str]]] = None,
                           output_file: Optional[pulumi.Input[Optional[str]]] = None,
                           page_number: Optional[pulumi.Input[Optional[int]]] = None,
                           page_size: Optional[pulumi.Input[Optional[int]]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetActivationsResult]:
    """
    This data source provides the Ecs Activations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.177.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ecs.get_activations()
    pulumi.export("ecsActivationId1", ids.activations[0].id)
    ```


    :param Sequence[str] ids: A list of Activation IDs.
    :param str instance_name: The default prefix of the instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    ...
